@@ -27,44 +27,29 @@ sasconnection = {{'java'      : '{java}',
     return saspy_conn
 
 
-class Abstract_SAS(saspy.SASsession):
+class AbstractSAS(saspy.SASsession):
     def __init__(self, sasobjsp_user,
                        sasobjsp_pass,
                        sasobjsp_host,
                        sasobjsp_port,
                        java='/usr/bin/java',
                        **kwargs):
-        logging.debug('Initializing Abstrac sas class')
+        logging.debug('Initializing Abstract SAS class')
         self.sasobjsp_host = sasobjsp_host
         self.sasobjsp_port = sasobjsp_port
         self.sasobjsp_user = sasobjsp_user
         self.sasobjsp_pass = sasobjsp_pass
         self.java = java
-        self.connected = False
         logging.debug('Generating saspy conn file')
         self.saspy_conn = create_saspyconn(sasobjsp_host=self.sasobjsp_host,
                                            sasobjsp_port=self.sasobjsp_port,
                                            java=self.java)
         logging.debug(f'Generated saspy conn file {self.saspy_conn.name}')
-        super(Abstract_SAS, self).__init__(cfgfile=self.saspy_conn.name,
+        super(AbstractSAS, self).__init__(cfgfile=self.saspy_conn.name,
                                            cfgname='sasconnection',
                                            omruser=self.sasobjsp_user,
                                            omrpw=self.sasobjsp_pass)
 
-    # def connect(self):
-    #     connection = get_sas_connect(sasobjsp_host=self.sasobjsp_host,
-    #                                  sasobjsp_port=self.sasobjsp_port,
-    #                                  sasobjsp_user=self.sasobjsp_user,
-    #                                  sasobjsp_pass=self.sasobjsp_pass)
-    #     if connection:
-    #         self.connected = True
-    #         return self
-
-    def disconnect(self):
-        if self.connected:
-            self.endsas()
-            self.connected = False
-
     def read_dataset(self, libname, tablename):
         df = self.sasdata2dataframe(table=tablename, libref=libname)
         return df
